function separatingF(func, par ,x0, x1, step)
% function separatingF(func, par ,x0, x1, step)
% the function classifies points evenly sampled in a visualization area,
% according to the classifier func
%
% func - classification function, eg kNNClassify 
% par - parameters list for the classification function
% x0 - position of the bottom-left corner of the visualization area, eg
% [-1,-1]
% x1 - position of the top-right corner of the visualization area, eg [1,1]
% step - step size controling the sampling of the visualization area
%
% EXAMPLE - separatingF(@kNNClassify,{X2, Y2, 'l2dist',[], 3},[-1,-1],[2,2],0.05)

    X = createGridPoints(x0, x1, step);

    Y = func(par{:}, X);
    
    intY = [min(Y); (min(Y) + max(Y))/2; max(Y)];
    
    if size(X,2) == 2
        x = x0(1):step:x1(1);
        y = x0(2):step:x1(2);
        contourf(x, y, reshape(Y,numel(x),numel(y)), intY);
    else size(X,2) == 3
        x = x0(1):step:x1(1);
        y = x0(2):step:x1(2);
        z = x0(3):step:x1(3);
        contour3(x,y,z, reshape(Y,numel(x),numel(y),numel(z)), intY);
    end

end
